@@ -62,7 +62,6 @@ define usekernprocpathname 'undef'
 define uselongdouble 'undef'
 define usemallocwrap 'define'
 define usemorebits 'undef'
-define usemultiplicity 'undef'
 define usemymalloc 'n'
 define usenamedanoncv 'undef'
 define usenm 'false'
@@ -167,7 +166,7 @@ define d_pseudofork 'undef'
 define d_dlsymun 'undef'
 define d_fcntl_can_lock 'undef'
 define d_sprintf_returns_strlen 'define'
-define d_u32align 'undef'
+define d_u32align 'define'
 define d_dir_dd_fd 'undef'
 define d_old_pthread_create_joinable 'undef'
 define d_oldpthreads 'undef'
